@@ -60,3 +60,6 @@ class ApiAccount(ApiBase):
 
     def submit_new_user_survey(self) -> str:
         return self.build_route(f"accounts/roles_and_technologies")
+
+    def get_user_spaces(self):
+        return self.build_route("accounts/user_spaces")
