@@ -32,6 +32,9 @@ class ApiSpaces(ApiBase):
         if repository_type == 'bitbucket':
             return self.space_bitbucket_repositories(space_name)
 
+        if repository_type == 'gitlab':
+            return self.space_gitlab_repositories(space_name)
+
         return self.space_github_repositories(space_name)
 
     def space_cloud_accounts(self, space_name: str):
@@ -62,6 +65,11 @@ class ApiSpaces(ApiBase):
             "spaces/{space_name}/repositories/bitbucket".format(**locals())
         )
 
+    def space_gitlab_repositories(self, space_name: str):
+        return self.build_route(
+            "spaces/{space_name}/repositories/gitlab".format(**locals())
+        )
+
     def user_permissions(self, space_name: str):
         return self.build_route("spaces/{space_name}/user_permissions".format(**locals()))
 
