@@ -1020,9 +1020,9 @@ class Colony:
         GatewayUtils.handle_response(response, [200])
         return json.loads(response.text)
 
-    def create_space(self, space_name: str, cloud_accounts: List[str] = None):
+    def create_space(self, space_name: str, cloud_accounts: List[str] = None, color: str = None, icon: str = None):
         url = self._api_root.spaces.spaces()
-        request = {"name": space_name, "cloud_accounts": cloud_accounts}
+        request = {"name": space_name, "cloud_accounts": cloud_accounts, "color": color, "icon": icon}
 
         response = self.session.post(url=url, json=request)
         GatewayUtils.handle_response(response=response, return_codes=[200])
@@ -1818,6 +1818,12 @@ class Colony:
         response = self.session.post(url=forgot_account_url, json=request)
         GatewayUtils.handle_response(response, [200])
 
+    def get_user_spaces(self):
+        method_url = self._api_root.account.get_user_spaces()
+        res = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        spaces_json = json.loads(res.text)
+        return spaces_json
 
 class SandboxesHandler:
     def __init__(self):
