@@ -85,6 +85,8 @@ class Converters:
             admins=admins,
             users_count=space["users_count"],
             cloud_accounts=space_cloud_accounts,
+            color=space["color"],
+            icon=space["icon"]
         )
 
     @staticmethod
@@ -153,6 +155,7 @@ class Converters:
             if catalog["tags"]
             else [],
             policy=Converters.create_blueprint_policy_response(catalog["policies"]),
+            spec_version=catalog.get("spec_version")
         )
 
     @staticmethod
@@ -247,6 +250,7 @@ class Converters:
             if blueprint["tags"]
             else [],
             policy=Converters.create_blueprint_policy_response(blueprint["policies"]),
+            spec_version=blueprint.get("spec_version")
         )
 
     @staticmethod
