@@ -108,8 +108,10 @@ class CreateAccountRequest:
 
 
 class UpdateSpaceRequest:
-    def __init__(self, name: str):
+    def __init__(self, name: str = None, color: str = None, icon: str = None):
         self.name = name
+        self.color = color
+        self.icon = icon
 
 
 class AddK8SComputeServiceToSpaceRequest:
