@@ -162,7 +162,8 @@ class CatalogForGetAllResponse:
             artifacts: Dict[str, str],
             errors: [],
             tags: List[BlueprintTagResponse],
-            policy: BlueprintPolicyResponse
+            policy: BlueprintPolicyResponse,
+            spec_version: str
     ):
         self.links = links
         self.url = url
@@ -175,6 +176,7 @@ class CatalogForGetAllResponse:
         self.errors = errors
         self.tags = tags
         self.policy = policy
+        self.spec_version = spec_version
 
 
 class BlueprintApplicationResponse:
@@ -270,7 +272,8 @@ class BlueprintResponse:
             services: List[BlueprintServiceResponse],
             environment_type: str,
             tags: List[BlueprintTagResponse],
-            policy: BlueprintPolicyResponse
+            policy: BlueprintPolicyResponse,
+            spec_version: str
     ):
         self.errors = errors
         self.is_sample = is_sample
@@ -289,6 +292,7 @@ class BlueprintResponse:
         self.environment_type = environment_type
         self.tags = tags
         self.policy = policy
+        self.spec_version = spec_version
 
 
 class SourceControlDetailsResponse:
@@ -638,6 +642,7 @@ class TagType(Enum):
     SYSTEM = 'system'
     PRE_DEFINED = 'pre_defined'
     USER_DEFINED = 'user_defined'
+    OVERRIDE = 'override'
 
 
 class TagResponse:
@@ -1257,6 +1262,8 @@ class SpaceCloudAccount:
 class GetSpaceResponse:
     def __init__(self, space: {}):
         self.name = space["name"]
+        self.color = space["color"]
+        self.icon = space["icon"]
 
 
 class GetSpacesResponse:
@@ -1266,11 +1273,15 @@ class GetSpacesResponse:
             admins: List[SpaceAdmin],
             users_count: int,
             cloud_accounts: List[SpaceCloudAccount],
+            color,
+            icon
     ):
         self.users_count = users_count
         self.cloud_accounts = cloud_accounts
         self.admins = admins
         self.name = name
+        self.color = color
+        self.icon = icon
 
 
 class RoleListItemResponse:
