@@ -119,3 +119,8 @@ class TagScopes:
     SPACE_TAG_SCOPE = 'space'
     BLUEPRINT_TAG_SCOPE = 'blueprint'
     RUNTIME_TAG_SCOPE = 'runtime'
+
+
+class SpecVersions:
+    V1 = "1"
+    V2_Preview = "2-preview"
