@@ -23,7 +23,14 @@ class NSession(requests.Session):
 
         return self._session.get(url=url, **kwargs)
 
-    def post(self, url, data=None, json=None, **kwargs):
+    def post(self, url, data=None, json: {}=None, **kwargs):
+        """
+        :param url:
+        :param data:
+        :param json: Dictionary object. Send your object using my_obj.__dict__
+        :param kwargs:
+        :return:
+        """
 
         if kwargs.get("timeout", None) is None:
             kwargs.update({"timeout": self.default_timeout})
